@@ -3,17 +3,15 @@ package Lingua::IN::R::TGC;
 use Moose::Role;
 use utf8;
 use v5.22;
-use experimentals;
 use Function::Parameters;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 # ar hash is written according to http://unicode.org/charts
 # each key in the hash is a combination of a consonant and the virama
-# please send me a message if you find something to change
 
 # suported scripts are telugu, kannada , tamil, malayalam, devanagari, oriya, gujarati, gurmukhi, bengali
-# to support other scripts, combine each consonant with virama, add them to the hash
+# to support other scripts, combine each consonant with virama, add them to the hash.
 
 has 'ar' => (
   is      => 'ro',
