@@ -1,6 +1,6 @@
 package Lingua::IN::TGC;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use 5.022002;
 use Moose;
@@ -19,7 +19,7 @@ Lingua::IN::TGC - Perl extension for tailored grapheme clusters for indian langu
 
   use Lingua::IN::TGC;
   my $t = Lingua::IN::TGC->new();
-  my @res = $t->TGC("రాజ్కుమార్రెడ్డి");
+  my @res = $t->TGC(string => "రాజ్కుమార్రెడ్డి");
   print join("\n", @res);
 
 =head1 DESCRIPTION
